@@ -1,8 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Region core functionality.
+"""
+Region core functionality.
 """
 from .core import *
 from .pixcoord import *
-from .compound import *
 from .mask import *
 from .bounding_box import *
+from .compound import *
+from .attributes import *
