@@ -49,8 +49,6 @@ class BoundingBox(object):
     >>> # "extent" is useful when plotting the BoundingBox with matplotlib
     >>> bbox.extent  # matplotlib order: (x, y)
     (0.5, 9.5, 1.5, 19.5)
-    >>> print(bbox.as_artist())
-    Rectangle(0.5,1.5;9x18)
     """
 
     def __init__(self, ixmin, ixmax, iymin, iymax):
@@ -134,6 +132,12 @@ class BoundingBox(object):
             (self.iymax == other.iymax)
         )
 
+    def __or__(self, other):
+        return self.union(other)
+
+    def __and__(self, other):
+        return self.intersection(other)
+
     def __repr__(self):
         data = self.__dict__
         data['name'] = self.__class__.__name__
@@ -257,3 +261,61 @@ class BoundingBox(object):
 
         reg = self.to_region()
         return reg.plot(origin=origin, ax=ax, **kwargs)
+
+    def union(self, other):
+        """
+        Return a `BoundingBox` representing the union of this
+        `BoundingBox` with another `BoundingBox`.
+
+        Parameters
+        ----------
+        other : `~photutils.BoundingBox`
+            The `BoundingBox` to join with this one.
+
+        Returns
+        -------
+        result : `~photutils.BoundingBox`
+            A `BoundingBox` representing the union of the input
+            `BoundingBox` with this one.
+        """
+
+        if not isinstance(other, BoundingBox):
+            raise TypeError('BoundingBox can be joined only with another '
+                            'BoundingBox.')
+
+        ixmin = min((self.ixmin, other.ixmin))
+        ixmax = max((self.ixmax, other.ixmax))
+        iymin = min((self.iymin, other.iymin))
+        iymax = max((self.iymax, other.iymax))
+
+        return BoundingBox(ixmin=ixmin, ixmax=ixmax, iymin=iymin, iymax=iymax)
+
+    def intersection(self, other):
+        """
+        Return a `BoundingBox` representing the intersection of this
+        `BoundingBox` with another `BoundingBox`.
+
+        Parameters
+        ----------
+        other : `~photutils.BoundingBox`
+            The `BoundingBox` to intersect with this one.
+
+        Returns
+        -------
+        result : `~photutils.BoundingBox`
+            A `BoundingBox` representing the intersection of the input
+            `BoundingBox` with this one.
+        """
+
+        if not isinstance(other, BoundingBox):
+            raise TypeError('BoundingBox can be intersected only with '
+                            'another BoundingBox.')
+
+        ixmin = max(self.ixmin, other.ixmin)
+        ixmax = min(self.ixmax, other.ixmax)
+        iymin = max(self.iymin, other.iymin)
+        iymax = min(self.iymax, other.iymax)
+        if ixmax < ixmin or iymax < iymin:
+            return None
+
+        return BoundingBox(ixmin=ixmin, ixmax=ixmax, iymin=iymin, iymax=iymax)
