@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import numpy as np
 from numpy.testing import assert_equal, assert_allclose
 import pytest
+from astropy import units as u
 from ..._utils.examples import make_example_dataset
 from ..pixcoord import PixCoord
 
@@ -14,6 +15,23 @@ def wcs():
     return dataset.wcs
 
 
+def test_pixcoord_copy_scalar():
+    p = PixCoord(x=1, y=2)
+    p2 = p.copy()
+    p.x = 99
+    p.y = 99
+    assert p2.xy == (1, 2)
+
+
+def test_pixcoord_copy_array():
+    p = PixCoord(x=[1, 2], y=[3, 4])
+    p2 = p.copy()
+    p.x[0] = 99
+    p.y[0] = 99
+    assert_equal(p2.x, [1, 2])
+    assert_equal(p2.y, [3, 4])
+
+
 def test_pixcoord_basic_dimension():
     with pytest.raises(ValueError):
         PixCoord(np.array([1, 2]), [3, 4, 5, 6])
@@ -131,7 +149,7 @@ def test_pixcoord_to_sky_array_1d(wcs):
 
     p2 = PixCoord.from_sky(skycoord=s, wcs=wcs)
     assert isinstance(p2.x, np.ndarray)
-    assert p2.x.shape == (2, )
+    assert p2.x.shape == (2,)
     assert not p2.isscalar
 
     assert p == p2
@@ -185,7 +203,7 @@ def test_pixcoord_separation_array_2d():
 def test_equality():
     a = np.array([1, 2])
     b = PixCoord(a[0], a[1])
-    c = PixCoord(a[0]+0.0000001, a[1])
+    c = PixCoord(a[0] + 0.0000001, a[1])
 
     assert not b == a
     assert b == b
@@ -203,3 +221,25 @@ def test_equality():
 
     assert a == b
     assert a == a
+
+
+def test_pixcoord_xy():
+    a = np.array([1, 2])
+    pc = PixCoord(a[0], a[1])
+
+    assert pc.xy[0] == pc.x
+    assert pc.xy[1] == pc.y
+
+
+def test_pixcoord_rotate_scalar():
+    point = PixCoord(3, 4)
+    center = PixCoord(2, 3)
+    point = point.rotate(center, 90 * u.deg)
+    assert_allclose(point.xy, (1, 4))
+
+
+def test_pixcoord_rotate_array():
+    point = PixCoord([3, 3], [4, 4])
+    center = PixCoord(2, 3)
+    point = point.rotate(center, 90 * u.deg)
+    assert_allclose(point.xy, ([1, 1], [4, 4]))
