@@ -6,3 +6,6 @@ from .ellipse import *
 from .point import *
 from .polygon import *
 from .rectangle import *
+from .annulus import *
+from .line import *
+from .text import *
