@@ -62,7 +62,6 @@ class EllipsePixelRegion(PixelRegion):
         patch = reg.as_artist(facecolor='none', edgecolor='red', lw=2)
         ax.add_patch(patch)
 
-        plt.show()
     """
 
     center = ScalarPix('center')
@@ -186,8 +185,8 @@ class EllipsePixelRegion(PixelRegion):
         """
         Matplotlib patch object for this region (`matplotlib.patches.Ellipse`).
 
-        Parameters:
-        -----------
+        Parameters
+        ----------
         origin : array_like, optional
             The ``(x, y)`` pixel position of the origin of the displayed image.
             Default is (0, 0).
@@ -213,6 +212,27 @@ class EllipsePixelRegion(PixelRegion):
         return Ellipse(xy=xy, width=width, height=height, angle=angle,
                        **mpl_params)
 
+    def rotate(self, center, angle):
+        """Make a rotated region.
+
+        Rotates counter-clockwise for positive ``angle``.
+
+        Parameters
+        ----------
+        center : `PixCoord`
+            Rotation center point
+        angle : `~astropy.coordinates.Angle`
+            Rotation angle
+
+        Returns
+        -------
+        region : `EllipsePixelRegion`
+            Rotated region (an independent copy)
+        """
+        center = self.center.rotate(center, angle)
+        angle = self.angle + angle
+        return self.copy(center=center, angle=angle)
+
 
 class EllipseSkyRegion(SkyRegion):
     """
