@@ -47,7 +47,6 @@ class PointPixelRegion(PixelRegion):
         plt.xlim(0, 6)
         plt.ylim(0, 6)
         ax.set_aspect('equal')
-        plt.show()
 
     """
 
@@ -57,7 +56,7 @@ class PointPixelRegion(PixelRegion):
         self.center = center
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = None
+        self._repr_params = tuple()
 
     @property
     def area(self):
@@ -116,6 +115,26 @@ class PointPixelRegion(PixelRegion):
 
         return point
 
+    def rotate(self, center, angle):
+        """Make a rotated region.
+
+        Rotates counter-clockwise for positive ``angle``.
+
+        Parameters
+        ----------
+        center : `PixCoord`
+            Rotation center point
+        angle : `~astropy.coordinates.Angle`
+            Rotation angle
+
+        Returns
+        -------
+        region : `PointPixelRegion`
+            Rotated region (an independent copy)
+        """
+        center = self.center.rotate(center, angle)
+        return self.copy(center=center)
+
 
 class PointSkyRegion(SkyRegion):
     """
@@ -137,7 +156,7 @@ class PointSkyRegion(SkyRegion):
         self.center = center
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = None
+        self._repr_params = tuple()
 
     def contains(self, skycoord, wcs):
         if self.meta.get('include', True):
