@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
-
 import numpy as np
 
 from astropy.wcs.utils import skycoord_to_pixel, pixel_to_skycoord
@@ -48,7 +47,6 @@ class PolygonPixelRegion(PixelRegion):
         plt.xlim(30, 80)
         plt.ylim(50, 80)
         ax.set_aspect('equal')
-        plt.show()
     """
 
     vertices = OneDPix('vertices')
@@ -128,8 +126,8 @@ class PolygonPixelRegion(PixelRegion):
         """
         Matplotlib patch object for this region (`matplotlib.patches.Polygon`).
 
-        Parameters:
-        -----------
+        Parameters
+        ----------
         origin : array_like, optional
             The ``(x, y)`` pixel position of the origin of the displayed image.
             Default is (0, 0).
@@ -150,6 +148,26 @@ class PolygonPixelRegion(PixelRegion):
 
         return Polygon(xy=xy, **mpl_params)
 
+    def rotate(self, center, angle):
+        """Make a rotated region.
+
+        Rotates counter-clockwise for positive ``angle``.
+
+        Parameters
+        ----------
+        center : `PixCoord`
+            Rotation center point
+        angle : `~astropy.coordinates.Angle`
+            Rotation angle
+
+        Returns
+        -------
+        region : `PolygonPixelRegion`
+            Rotated region (an independent copy)
+        """
+        vertices = self.vertices.rotate(center, angle)
+        return self.copy(vertices=vertices)
+
 
 class PolygonSkyRegion(SkyRegion):
     """
