@@ -16,7 +16,7 @@ from astropy.wcs import WCS
 from ...core import PixCoord
 from ...tests.helpers import make_simple_wcs
 from ..circle import CirclePixelRegion, CircleSkyRegion
-from .utils import ASTROPY_LT_13, HAS_MATPLOTLIB  # noqa
+from .utils import HAS_MATPLOTLIB  # noqa
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
 
 
@@ -28,7 +28,6 @@ def wcs():
 
 
 class TestCirclePixelRegion(BaseTestPixelRegion):
-
     reg = CirclePixelRegion(PixCoord(3, 4), radius=2)
     sample_box = [0, 6, 1, 7]
     inside = [(3, 4)]
@@ -37,6 +36,13 @@ class TestCirclePixelRegion(BaseTestPixelRegion):
     expected_repr = '<CirclePixelRegion(PixCoord(x=3, y=4), radius=2)>'
     expected_str = 'Region: CirclePixelRegion\ncenter: PixCoord(x=3, y=4)\nradius: 2'
 
+    def test_copy(self):
+        reg = self.reg.copy()
+        assert reg.center.xy == (3, 4)
+        assert reg.radius == 2
+        assert reg.visual == {}
+        assert reg.meta == {}
+
     def test_pix_sky_roundtrip(self):
         wcs = make_simple_wcs(SkyCoord(2 * u.deg, 3 * u.deg), 0.1 * u.deg, 20)
         reg_new = self.reg.to_sky(wcs).to_pixel(wcs)
@@ -50,23 +56,26 @@ class TestCirclePixelRegion(BaseTestPixelRegion):
         assert_allclose(patch.center, (3, 4))
         assert_allclose(patch.radius, 2)
 
+    def test_rotate(self):
+        reg = self.reg.rotate(PixCoord(2, 3), 90 * u.deg)
+        assert_allclose(reg.center.xy, (1, 4))
+
 
 class TestCircleSkyRegion(BaseTestSkyRegion):
-
     reg = CircleSkyRegion(SkyCoord(3 * u.deg, 4 * u.deg), 2 * u.arcsec)
 
-    if ASTROPY_LT_13:
-        expected_repr = ('<CircleSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                         'deg\n    (3.0, 4.0)>, radius=2.0 arcsec)>')
-        expected_str = ('Region: CircleSkyRegion\ncenter: <SkyCoord (ICRS): '
-                        '(ra, dec) in deg\n    (3.0, 4.0)>\nradius: 2.0 '
-                        'arcsec')
-    else:
-        expected_repr = ('<CircleSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                         'deg\n    ( 3.,  4.)>, radius=2.0 arcsec)>')
-        expected_str = ('Region: CircleSkyRegion\ncenter: <SkyCoord (ICRS): '
-                        '(ra, dec) in deg\n    ( 3.,  4.)>\nradius: 2.0 '
-                        'arcsec')
+    expected_repr = ('<CircleSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
+                     'deg\n    ( 3.,  4.)>, radius=2.0 arcsec)>')
+    expected_str = ('Region: CircleSkyRegion\ncenter: <SkyCoord (ICRS): '
+                    '(ra, dec) in deg\n    ( 3.,  4.)>\nradius: 2.0 '
+                    'arcsec')
+
+    def test_copy(self):
+        reg = self.reg.copy()
+        assert_allclose(reg.center.ra.deg, 3)
+        assert_allclose(reg.radius.to_value("arcsec"), 2)
+        assert reg.visual == {}
+        assert reg.meta == {}
 
     def test_transformation(self, wcs):
         skycoord = SkyCoord(3 * u.deg, 4 * u.deg, frame='galactic')
