@@ -16,7 +16,7 @@ from astropy.wcs import WCS
 from ...core import PixCoord
 from ...tests.helpers import make_simple_wcs
 from ..ellipse import EllipsePixelRegion, EllipseSkyRegion
-from .utils import ASTROPY_LT_13, HAS_MATPLOTLIB  # noqa
+from .utils import HAS_MATPLOTLIB  # noqa
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
 
 
@@ -28,7 +28,6 @@ def wcs():
 
 
 class TestEllipsePixelRegion(BaseTestPixelRegion):
-
     reg = EllipsePixelRegion(center=PixCoord(3, 4), width=4, height=3, angle=5 * u.deg)
     sample_box = [-2, 8, -1, 9]
     inside = [(4.5, 4)]
@@ -38,6 +37,15 @@ class TestEllipsePixelRegion(BaseTestPixelRegion):
     expected_str = ('Region: EllipsePixelRegion\ncenter: PixCoord(x=3, y=4)\n'
                     'width: 4\nheight: 3\nangle: 5.0 deg')
 
+    def test_copy(self):
+        reg = self.reg.copy()
+        assert reg.center.xy == (3, 4)
+        assert reg.width == 4
+        assert reg.height == 3
+        assert_allclose(reg.angle.to_value("deg"), 5)
+        assert reg.visual == {}
+        assert reg.meta == {}
+
     def test_pix_sky_roundtrip(self):
         wcs = make_simple_wcs(SkyCoord(2 * u.deg, 3 * u.deg), 0.1 * u.deg, 20)
         reg_new = self.reg.to_sky(wcs).to_pixel(wcs)
@@ -70,9 +78,13 @@ class TestEllipsePixelRegion(BaseTestPixelRegion):
                                  angle=90. * u.deg)
         assert reg.bounding_box.shape == (a, b)
 
+    def test_rotate(self):
+        reg = self.reg.rotate(PixCoord(2, 3), 90 * u.deg)
+        assert_allclose(reg.center.xy, (1, 4))
+        assert_allclose(reg.angle.to_value("deg"), 95)
+
 
 class TestEllipseSkyRegion(BaseTestSkyRegion):
-
     reg = EllipseSkyRegion(
         center=SkyCoord(3, 4, unit='deg'),
         width=4 * u.deg,
@@ -80,20 +92,21 @@ class TestEllipseSkyRegion(BaseTestSkyRegion):
         angle=5 * u.deg,
     )
 
-    if ASTROPY_LT_13:
-        expected_repr = ('<EllipseSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                    'deg\n    (3.0, 4.0)>, width=4.0 deg, height=3.0 deg,'
-                    ' angle=5.0 deg)>')
-        expected_str = ('Region: EllipseSkyRegion\ncenter: <SkyCoord (ICRS): '
-                   '(ra, dec) in deg\n    (3.0, 4.0)>\nwidth: 4.0 deg\n'
-                   'height: 3.0 deg\nangle: 5.0 deg')
-    else:
-        expected_repr = ('<EllipseSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                    'deg\n    ( 3.,  4.)>, width=4.0 deg, height=3.0 deg,'
-                    ' angle=5.0 deg)>')
-        expected_str = ('Region: EllipseSkyRegion\ncenter: <SkyCoord (ICRS): '
-                   '(ra, dec) in deg\n    ( 3.,  4.)>\nwidth: 4.0 deg\n'
-                   'height: 3.0 deg\nangle: 5.0 deg')
+    expected_repr = ('<EllipseSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
+                     'deg\n    ( 3.,  4.)>, width=4.0 deg, height=3.0 deg,'
+                     ' angle=5.0 deg)>')
+    expected_str = ('Region: EllipseSkyRegion\ncenter: <SkyCoord (ICRS): '
+                    '(ra, dec) in deg\n    ( 3.,  4.)>\nwidth: 4.0 deg\n'
+                    'height: 3.0 deg\nangle: 5.0 deg')
+
+    def test_copy(self):
+        reg = self.reg.copy()
+        assert_allclose(reg.center.ra.deg, 3)
+        assert_allclose(reg.width.to_value("deg"), 4)
+        assert_allclose(reg.height.to_value("deg"), 3)
+        assert_allclose(reg.angle.to_value("deg"), 5)
+        assert reg.visual == {}
+        assert reg.meta == {}
 
     def test_dimension_center(self):
         center = SkyCoord([1, 2] * u.deg, [3, 4] * u.deg)
