@@ -15,7 +15,7 @@ from astropy.wcs import WCS
 from ...core import PixCoord
 from ..rectangle import RectanglePixelRegion, RectangleSkyRegion
 from ...tests.helpers import make_simple_wcs
-from .utils import ASTROPY_LT_13, HAS_MATPLOTLIB  # noqa
+from .utils import HAS_MATPLOTLIB  # noqa
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
 
 
@@ -67,6 +67,15 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
     expected_str = ('Region: RectanglePixelRegion\ncenter: PixCoord(x=3, y=4)\n'
                     'width: 4\nheight: 3\nangle: 5.0 deg')
 
+    def test_copy(self):
+        reg = self.reg.copy()
+        assert reg.center.xy == (3, 4)
+        assert reg.width == 4
+        assert reg.height == 3
+        assert_allclose(reg.angle.to_value("deg"), 5)
+        assert reg.visual == {}
+        assert reg.meta == {}
+
     def test_pix_sky_roundtrip(self):
         wcs = make_simple_wcs(SkyCoord(2 * u.deg, 3 * u.deg), 0.1 * u.deg, 20)
         reg_new = self.reg.to_sky(wcs).to_pixel(wcs)
@@ -93,6 +102,11 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
         # correctly.
         # assert_allclose(patch._angle, 5)
 
+    def test_rotate(self):
+        reg = self.reg.rotate(PixCoord(2, 3), 90 * u.deg)
+        assert_allclose(reg.center.xy, (1, 4))
+        assert_allclose(reg.angle.to_value("deg"), 95)
+
 
 def test_rectangular_pixel_region_bbox():
     # odd sizes
@@ -135,20 +149,21 @@ class TestRectangleSkyRegion(BaseTestSkyRegion):
         angle=5 * u.deg,
     )
 
-    if ASTROPY_LT_13:
-        expected_repr = ('<RectangleSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                    'deg\n    (3.0, 4.0)>, width=4.0 deg, height=3.0 '
-                    'deg, angle=5.0 deg)>')
-        expected_str = ('Region: RectangleSkyRegion\ncenter: <SkyCoord '
-                   '(ICRS): (ra, dec) in deg\n    (3.0, 4.0)>\nwidth: '
-                   '4.0 deg\nheight: 3.0 deg\nangle: 5.0 deg')
-    else:
-        expected_repr = ('<RectangleSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                    'deg\n    ( 3.,  4.)>, width=4.0 deg, height=3.0 '
-                    'deg, angle=5.0 deg)>')
-        expected_str = ('Region: RectangleSkyRegion\ncenter: <SkyCoord '
-                   '(ICRS): (ra, dec) in deg\n    ( 3.,  4.)>\nwidth: '
-                   '4.0 deg\nheight: 3.0 deg\nangle: 5.0 deg')
+    expected_repr = ('<RectangleSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
+                'deg\n    ( 3.,  4.)>, width=4.0 deg, height=3.0 '
+                'deg, angle=5.0 deg)>')
+    expected_str = ('Region: RectangleSkyRegion\ncenter: <SkyCoord '
+               '(ICRS): (ra, dec) in deg\n    ( 3.,  4.)>\nwidth: '
+               '4.0 deg\nheight: 3.0 deg\nangle: 5.0 deg')
+
+    def test_copy(self):
+        reg = self.reg.copy()
+        assert_allclose(reg.center.ra.deg, 3)
+        assert_allclose(reg.width.to_value("deg"),  4)
+        assert_allclose(reg.height.to_value("deg"), 3)
+        assert_allclose(reg.angle.to_value("deg"), 5)
+        assert reg.visual == {}
+        assert reg.meta == {}
 
     def test_contains(self, wcs):
         position = SkyCoord([1, 3] * u.deg, [2, 4] * u.deg)
